require_relative '../lib/trailfinder'

# This is for colors in the terminal
RSpec.configure do |config|
  config.failure_color = :red
  config.tty = true
  config.color = true
end

describe Trailfinder do
  let(:trail) { Trailfinder.new }

  describe '#get_trails_by_id' do
    context 'when a single id is given' do
      context 'when the id is valid'
        let(:response) { trail.get_trails_by_id(7000108)}
        let(:subject) { response['trails'].first['name']}
        
        it 'returns the trail data' do
          expect(subject).to eq('Angels Landing')
        end
        
      context 'when the id is invalid' do
        let(:response) { trail.get_trails_by_id(1)}
        let(:subject) { response }
        
        it 'returns a blank array' do
          expect(subject).to eq([])
        end
      end
    end
      
    context 'when an array of valid ids is given' do
      context 'when all the values are valid' do
        let(:response) { trail.get_trails_by_id([7001635, 7002742]) }
        let(:subject) { response['trails'].size }
        
        it 'returns an array of trails' do 
          expect(subject).to eq(2)
        end
      end
      
      context 'when some of the values are valid' do
        let(:response) { trail.get_trails_by_id([7001635, 999999999]) }
        let(:subject) { response['trails'].size }
        
        it 'returns only the valid trails' do
          expect(subject).to eq(1)
        end
      end
      
      context 'when none of the values are valid' do
        let(:response) { trail.get_trails_by_id([99999998, 999999999]) }
        let(:subject) { response }
        
        it 'returns no trails' do
          expect(subject).to eq([])
        end
      end
    end

  end

  describe '#get_trails' do
    context 'with valid inputs' do
      context 'when there are trails within scope' do
        let(:response) { trail.get_trails(latitude: 40, longitude: -105) }
        let(:subject) { response['trails'].first['name'] }
        
        it 'returns a collection of trails' do
          expect(subject).to eq("Teller Farm - The Tank")
        end
      end
      
      context 'when there are no trails within scope' do
        let(:response) { trail.get_trails(latitude: 11, longitude: 111) }
        let(:subject) { response['trails'] }
        
        it 'returns an empty array' do
          expect(subject).to eq([])
        end
      end
    end
    
    context 'with invalid inputs' do
      let(:response) { trail.get_trails(latitude: 'abc', longitude: 'xyz') }
      let(:subject) { response }

      it 'returns an empty array' do
        expect(subject).to eq([])
      end
    end
  end
end